@@ -3,19 +3,19 @@
  */
 package org.gcube.portlets.user.td.openwidget.client;
 
-
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
+import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.TableData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.open.TDOpenSession;
-import org.gcube.portlets.user.td.openwidget.client.utils.UtilsGXT3;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.RibbonEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.RibbonType;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 import org.gcube.portlets.user.td.wizardwidget.client.WizardCard;
+import org.gcube.portlets.user.td.wizardwidget.client.util.UtilsGXT3;
 
 import com.allen_sauer.gwt.log.client.Log;
 import com.google.gwt.event.logical.shared.SelectionEvent;
@@ -150,16 +150,23 @@ public class TabResourcesSelectionCard extends WizardCard {
 
 			public void onFailure(Throwable caught) {
 				if (caught instanceof TDGWTSessionExpiredException) {
-					getEventBus()
-							.fireEvent(
-									new SessionExpiredEvent(
-											SessionExpiredType.EXPIREDONSERVER));
+					getEventBus().fireEvent(
+							new SessionExpiredEvent(
+									SessionExpiredType.EXPIREDONSERVER));
 				} else {
-					Log.error("Error on delete TabResource: "
-							+ caught.getLocalizedMessage());
-					UtilsGXT3.alert("Error",
-							"Error on delete TabResource: "
-									+ caught.getLocalizedMessage());
+					if (caught instanceof TDGWTIsLockedException) {
+						Log.error(caught.getLocalizedMessage());
+						UtilsGXT3.alert("Error Locked",
+								caught.getLocalizedMessage());
+					} else {
+						Log.error("Error on delete TabResource: "
+								+ caught.getLocalizedMessage());
+						UtilsGXT3.alert(
+								"Error",
+								"Error on delete TabResource: "
+										+ caught.getLocalizedMessage());
+					}
+
 				}
 
 			}
@@ -202,11 +209,20 @@ public class TabResourcesSelectionCard extends WizardCard {
 											new SessionExpiredEvent(
 													SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.error("Error on set TabResource: "
-									+ caught.getLocalizedMessage());
-							UtilsGXT3.alert("Error",
-									"Error on set TabResource: "
-											+ caught.getLocalizedMessage());
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+
+							} else {
+								Log.error("Error on set TabResource: "
+										+ caught.getLocalizedMessage());
+								UtilsGXT3.alert(
+										"Error",
+										"Error on set TabResource: "
+												+ caught.getLocalizedMessage());
+							}
+
 						}
 
 					}
